/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GkeHubFeatureMembershipConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the feature
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#feature GkeHubFeatureMembership#feature}
    */
    readonly feature: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#id GkeHubFeatureMembership#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location of the feature
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#location GkeHubFeatureMembership#location}
    */
    readonly location: string;
    /**
    * The name of the membership
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#membership GkeHubFeatureMembership#membership}
    */
    readonly membership: string;
    /**
    * The project of the feature
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#project GkeHubFeatureMembership#project}
    */
    readonly project?: string;
    /**
    * configmanagement block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#configmanagement GkeHubFeatureMembership#configmanagement}
    */
    readonly configmanagement?: GkeHubFeatureMembershipConfigmanagement;
    /**
    * mesh block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#mesh GkeHubFeatureMembership#mesh}
    */
    readonly mesh?: GkeHubFeatureMembershipMesh;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#timeouts GkeHubFeatureMembership#timeouts}
    */
    readonly timeouts?: GkeHubFeatureMembershipTimeouts;
}
export interface GkeHubFeatureMembershipConfigmanagementBinauthz {
    /**
    * Whether binauthz is enabled in this cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#enabled GkeHubFeatureMembership#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function gkeHubFeatureMembershipConfigmanagementBinauthzToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementBinauthzOutputReference | GkeHubFeatureMembershipConfigmanagementBinauthz): any;
export declare class GkeHubFeatureMembershipConfigmanagementBinauthzOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementBinauthz | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementBinauthz | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementConfigSyncGit {
    /**
    * The GCP Service Account Email used for auth when secretType is gcpServiceAccount.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#gcp_service_account_email GkeHubFeatureMembership#gcp_service_account_email}
    */
    readonly gcpServiceAccountEmail?: string;
    /**
    * URL for the HTTPS proxy to be used when communicating with the Git repo.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#https_proxy GkeHubFeatureMembership#https_proxy}
    */
    readonly httpsProxy?: string;
    /**
    * The path within the Git repository that represents the top level of the repo to sync. Default: the root directory of the repository.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#policy_dir GkeHubFeatureMembership#policy_dir}
    */
    readonly policyDir?: string;
    /**
    * Type of secret configured for access to the Git repo. Must be one of ssh, cookiefile, gcenode, token, gcpserviceaccount or none. The validation of this is case-sensitive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#secret_type GkeHubFeatureMembership#secret_type}
    */
    readonly secretType?: string;
    /**
    * The branch of the repository to sync from. Default: master.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_branch GkeHubFeatureMembership#sync_branch}
    */
    readonly syncBranch?: string;
    /**
    * The URL of the Git repository to use as the source of truth.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_repo GkeHubFeatureMembership#sync_repo}
    */
    readonly syncRepo?: string;
    /**
    * Git revision (tag or hash) to check out. Default HEAD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_rev GkeHubFeatureMembership#sync_rev}
    */
    readonly syncRev?: string;
    /**
    * Period in seconds between consecutive syncs. Default: 15.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_wait_secs GkeHubFeatureMembership#sync_wait_secs}
    */
    readonly syncWaitSecs?: string;
}
export declare function gkeHubFeatureMembershipConfigmanagementConfigSyncGitToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementConfigSyncGitOutputReference | GkeHubFeatureMembershipConfigmanagementConfigSyncGit): any;
export declare class GkeHubFeatureMembershipConfigmanagementConfigSyncGitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementConfigSyncGit | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementConfigSyncGit | undefined);
    private _gcpServiceAccountEmail?;
    get gcpServiceAccountEmail(): string;
    set gcpServiceAccountEmail(value: string);
    resetGcpServiceAccountEmail(): void;
    get gcpServiceAccountEmailInput(): string | undefined;
    private _httpsProxy?;
    get httpsProxy(): string;
    set httpsProxy(value: string);
    resetHttpsProxy(): void;
    get httpsProxyInput(): string | undefined;
    private _policyDir?;
    get policyDir(): string;
    set policyDir(value: string);
    resetPolicyDir(): void;
    get policyDirInput(): string | undefined;
    private _secretType?;
    get secretType(): string;
    set secretType(value: string);
    resetSecretType(): void;
    get secretTypeInput(): string | undefined;
    private _syncBranch?;
    get syncBranch(): string;
    set syncBranch(value: string);
    resetSyncBranch(): void;
    get syncBranchInput(): string | undefined;
    private _syncRepo?;
    get syncRepo(): string;
    set syncRepo(value: string);
    resetSyncRepo(): void;
    get syncRepoInput(): string | undefined;
    private _syncRev?;
    get syncRev(): string;
    set syncRev(value: string);
    resetSyncRev(): void;
    get syncRevInput(): string | undefined;
    private _syncWaitSecs?;
    get syncWaitSecs(): string;
    set syncWaitSecs(value: string);
    resetSyncWaitSecs(): void;
    get syncWaitSecsInput(): string | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementConfigSyncOci {
    /**
    * The GCP Service Account Email used for auth when secret_type is gcpserviceaccount.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#gcp_service_account_email GkeHubFeatureMembership#gcp_service_account_email}
    */
    readonly gcpServiceAccountEmail?: string;
    /**
    * The absolute path of the directory that contains the local resources. Default: the root directory of the image.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#policy_dir GkeHubFeatureMembership#policy_dir}
    */
    readonly policyDir?: string;
    /**
    * Type of secret configured for access to the OCI Image. Must be one of gcenode, gcpserviceaccount or none. The validation of this is case-sensitive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#secret_type GkeHubFeatureMembership#secret_type}
    */
    readonly secretType?: string;
    /**
    * The OCI image repository URL for the package to sync from. e.g. LOCATION-docker.pkg.dev/PROJECT_ID/REPOSITORY_NAME/PACKAGE_NAME.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_repo GkeHubFeatureMembership#sync_repo}
    */
    readonly syncRepo?: string;
    /**
    * Period in seconds(int64 format) between consecutive syncs. Default: 15.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#sync_wait_secs GkeHubFeatureMembership#sync_wait_secs}
    */
    readonly syncWaitSecs?: string;
}
export declare function gkeHubFeatureMembershipConfigmanagementConfigSyncOciToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementConfigSyncOciOutputReference | GkeHubFeatureMembershipConfigmanagementConfigSyncOci): any;
export declare class GkeHubFeatureMembershipConfigmanagementConfigSyncOciOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementConfigSyncOci | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementConfigSyncOci | undefined);
    private _gcpServiceAccountEmail?;
    get gcpServiceAccountEmail(): string;
    set gcpServiceAccountEmail(value: string);
    resetGcpServiceAccountEmail(): void;
    get gcpServiceAccountEmailInput(): string | undefined;
    private _policyDir?;
    get policyDir(): string;
    set policyDir(value: string);
    resetPolicyDir(): void;
    get policyDirInput(): string | undefined;
    private _secretType?;
    get secretType(): string;
    set secretType(value: string);
    resetSecretType(): void;
    get secretTypeInput(): string | undefined;
    private _syncRepo?;
    get syncRepo(): string;
    set syncRepo(value: string);
    resetSyncRepo(): void;
    get syncRepoInput(): string | undefined;
    private _syncWaitSecs?;
    get syncWaitSecs(): string;
    set syncWaitSecs(value: string);
    resetSyncWaitSecs(): void;
    get syncWaitSecsInput(): string | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementConfigSync {
    /**
    * Set to true to enable the Config Sync admission webhook to prevent drifts. If set to `false`, disables the Config Sync admission webhook and does not prevent drifts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#prevent_drift GkeHubFeatureMembership#prevent_drift}
    */
    readonly preventDrift?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether the Config Sync Repo is in "hierarchical" or "unstructured" mode.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#source_format GkeHubFeatureMembership#source_format}
    */
    readonly sourceFormat?: string;
    /**
    * git block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#git GkeHubFeatureMembership#git}
    */
    readonly git?: GkeHubFeatureMembershipConfigmanagementConfigSyncGit;
    /**
    * oci block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#oci GkeHubFeatureMembership#oci}
    */
    readonly oci?: GkeHubFeatureMembershipConfigmanagementConfigSyncOci;
}
export declare function gkeHubFeatureMembershipConfigmanagementConfigSyncToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementConfigSyncOutputReference | GkeHubFeatureMembershipConfigmanagementConfigSync): any;
export declare class GkeHubFeatureMembershipConfigmanagementConfigSyncOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementConfigSync | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementConfigSync | undefined);
    private _preventDrift?;
    get preventDrift(): boolean | cdktf.IResolvable;
    set preventDrift(value: boolean | cdktf.IResolvable);
    resetPreventDrift(): void;
    get preventDriftInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceFormat?;
    get sourceFormat(): string;
    set sourceFormat(value: string);
    resetSourceFormat(): void;
    get sourceFormatInput(): string | undefined;
    private _git;
    get git(): GkeHubFeatureMembershipConfigmanagementConfigSyncGitOutputReference;
    putGit(value: GkeHubFeatureMembershipConfigmanagementConfigSyncGit): void;
    resetGit(): void;
    get gitInput(): GkeHubFeatureMembershipConfigmanagementConfigSyncGit | undefined;
    private _oci;
    get oci(): GkeHubFeatureMembershipConfigmanagementConfigSyncOciOutputReference;
    putOci(value: GkeHubFeatureMembershipConfigmanagementConfigSyncOci): void;
    resetOci(): void;
    get ociInput(): GkeHubFeatureMembershipConfigmanagementConfigSyncOci | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementHierarchyController {
    /**
    * Whether hierarchical resource quota is enabled in this cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#enable_hierarchical_resource_quota GkeHubFeatureMembership#enable_hierarchical_resource_quota}
    */
    readonly enableHierarchicalResourceQuota?: boolean | cdktf.IResolvable;
    /**
    * Whether pod tree labels are enabled in this cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#enable_pod_tree_labels GkeHubFeatureMembership#enable_pod_tree_labels}
    */
    readonly enablePodTreeLabels?: boolean | cdktf.IResolvable;
    /**
    * Whether Hierarchy Controller is enabled in this cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#enabled GkeHubFeatureMembership#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function gkeHubFeatureMembershipConfigmanagementHierarchyControllerToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementHierarchyControllerOutputReference | GkeHubFeatureMembershipConfigmanagementHierarchyController): any;
export declare class GkeHubFeatureMembershipConfigmanagementHierarchyControllerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementHierarchyController | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementHierarchyController | undefined);
    private _enableHierarchicalResourceQuota?;
    get enableHierarchicalResourceQuota(): boolean | cdktf.IResolvable;
    set enableHierarchicalResourceQuota(value: boolean | cdktf.IResolvable);
    resetEnableHierarchicalResourceQuota(): void;
    get enableHierarchicalResourceQuotaInput(): boolean | cdktf.IResolvable | undefined;
    private _enablePodTreeLabels?;
    get enablePodTreeLabels(): boolean | cdktf.IResolvable;
    set enablePodTreeLabels(value: boolean | cdktf.IResolvable);
    resetEnablePodTreeLabels(): void;
    get enablePodTreeLabelsInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring {
    /**
    *  Specifies the list of backends Policy Controller will export to. Specifying an empty value `[]` disables metrics export.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#backends GkeHubFeatureMembership#backends}
    */
    readonly backends?: string[];
}
export declare function gkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoringToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoringOutputReference | GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring): any;
export declare class GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoringOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring | undefined);
    private _backends?;
    get backends(): string[];
    set backends(value: string[]);
    resetBackends(): void;
    get backendsInput(): string[] | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagementPolicyController {
    /**
    * Sets the interval for Policy Controller Audit Scans (in seconds). When set to 0, this disables audit functionality altogether.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#audit_interval_seconds GkeHubFeatureMembership#audit_interval_seconds}
    */
    readonly auditIntervalSeconds?: string;
    /**
    * Enables the installation of Policy Controller. If false, the rest of PolicyController fields take no effect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#enabled GkeHubFeatureMembership#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The set of namespaces that are excluded from Policy Controller checks. Namespaces do not need to currently exist on the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#exemptable_namespaces GkeHubFeatureMembership#exemptable_namespaces}
    */
    readonly exemptableNamespaces?: string[];
    /**
    * Logs all denies and dry run failures.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#log_denies_enabled GkeHubFeatureMembership#log_denies_enabled}
    */
    readonly logDeniesEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable or disable mutation in policy controller. If true, mutation CRDs, webhook and controller deployment will be deployed to the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#mutation_enabled GkeHubFeatureMembership#mutation_enabled}
    */
    readonly mutationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enables the ability to use Constraint Templates that reference to objects other than the object currently being evaluated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#referential_rules_enabled GkeHubFeatureMembership#referential_rules_enabled}
    */
    readonly referentialRulesEnabled?: boolean | cdktf.IResolvable;
    /**
    * Installs the default template library along with Policy Controller.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#template_library_installed GkeHubFeatureMembership#template_library_installed}
    */
    readonly templateLibraryInstalled?: boolean | cdktf.IResolvable;
    /**
    * monitoring block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#monitoring GkeHubFeatureMembership#monitoring}
    */
    readonly monitoring?: GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring;
}
export declare function gkeHubFeatureMembershipConfigmanagementPolicyControllerToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementPolicyControllerOutputReference | GkeHubFeatureMembershipConfigmanagementPolicyController): any;
export declare class GkeHubFeatureMembershipConfigmanagementPolicyControllerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagementPolicyController | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagementPolicyController | undefined);
    private _auditIntervalSeconds?;
    get auditIntervalSeconds(): string;
    set auditIntervalSeconds(value: string);
    resetAuditIntervalSeconds(): void;
    get auditIntervalSecondsInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _exemptableNamespaces?;
    get exemptableNamespaces(): string[];
    set exemptableNamespaces(value: string[]);
    resetExemptableNamespaces(): void;
    get exemptableNamespacesInput(): string[] | undefined;
    private _logDeniesEnabled?;
    get logDeniesEnabled(): boolean | cdktf.IResolvable;
    set logDeniesEnabled(value: boolean | cdktf.IResolvable);
    resetLogDeniesEnabled(): void;
    get logDeniesEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _mutationEnabled?;
    get mutationEnabled(): boolean | cdktf.IResolvable;
    set mutationEnabled(value: boolean | cdktf.IResolvable);
    resetMutationEnabled(): void;
    get mutationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _referentialRulesEnabled?;
    get referentialRulesEnabled(): boolean | cdktf.IResolvable;
    set referentialRulesEnabled(value: boolean | cdktf.IResolvable);
    resetReferentialRulesEnabled(): void;
    get referentialRulesEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _templateLibraryInstalled?;
    get templateLibraryInstalled(): boolean | cdktf.IResolvable;
    set templateLibraryInstalled(value: boolean | cdktf.IResolvable);
    resetTemplateLibraryInstalled(): void;
    get templateLibraryInstalledInput(): boolean | cdktf.IResolvable | undefined;
    private _monitoring;
    get monitoring(): GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoringOutputReference;
    putMonitoring(value: GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring): void;
    resetMonitoring(): void;
    get monitoringInput(): GkeHubFeatureMembershipConfigmanagementPolicyControllerMonitoring | undefined;
}
export interface GkeHubFeatureMembershipConfigmanagement {
    /**
    * Optional. Version of ACM to install. Defaults to the latest version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#version GkeHubFeatureMembership#version}
    */
    readonly version?: string;
    /**
    * binauthz block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#binauthz GkeHubFeatureMembership#binauthz}
    */
    readonly binauthz?: GkeHubFeatureMembershipConfigmanagementBinauthz;
    /**
    * config_sync block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#config_sync GkeHubFeatureMembership#config_sync}
    */
    readonly configSync?: GkeHubFeatureMembershipConfigmanagementConfigSync;
    /**
    * hierarchy_controller block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#hierarchy_controller GkeHubFeatureMembership#hierarchy_controller}
    */
    readonly hierarchyController?: GkeHubFeatureMembershipConfigmanagementHierarchyController;
    /**
    * policy_controller block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#policy_controller GkeHubFeatureMembership#policy_controller}
    */
    readonly policyController?: GkeHubFeatureMembershipConfigmanagementPolicyController;
}
export declare function gkeHubFeatureMembershipConfigmanagementToTerraform(struct?: GkeHubFeatureMembershipConfigmanagementOutputReference | GkeHubFeatureMembershipConfigmanagement): any;
export declare class GkeHubFeatureMembershipConfigmanagementOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipConfigmanagement | undefined;
    set internalValue(value: GkeHubFeatureMembershipConfigmanagement | undefined);
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _binauthz;
    get binauthz(): GkeHubFeatureMembershipConfigmanagementBinauthzOutputReference;
    putBinauthz(value: GkeHubFeatureMembershipConfigmanagementBinauthz): void;
    resetBinauthz(): void;
    get binauthzInput(): GkeHubFeatureMembershipConfigmanagementBinauthz | undefined;
    private _configSync;
    get configSync(): GkeHubFeatureMembershipConfigmanagementConfigSyncOutputReference;
    putConfigSync(value: GkeHubFeatureMembershipConfigmanagementConfigSync): void;
    resetConfigSync(): void;
    get configSyncInput(): GkeHubFeatureMembershipConfigmanagementConfigSync | undefined;
    private _hierarchyController;
    get hierarchyController(): GkeHubFeatureMembershipConfigmanagementHierarchyControllerOutputReference;
    putHierarchyController(value: GkeHubFeatureMembershipConfigmanagementHierarchyController): void;
    resetHierarchyController(): void;
    get hierarchyControllerInput(): GkeHubFeatureMembershipConfigmanagementHierarchyController | undefined;
    private _policyController;
    get policyController(): GkeHubFeatureMembershipConfigmanagementPolicyControllerOutputReference;
    putPolicyController(value: GkeHubFeatureMembershipConfigmanagementPolicyController): void;
    resetPolicyController(): void;
    get policyControllerInput(): GkeHubFeatureMembershipConfigmanagementPolicyController | undefined;
}
export interface GkeHubFeatureMembershipMesh {
    /**
    * **DEPRECATED** Whether to automatically manage Service Mesh control planes. Possible values: CONTROL_PLANE_MANAGEMENT_UNSPECIFIED, AUTOMATIC, MANUAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#control_plane GkeHubFeatureMembership#control_plane}
    */
    readonly controlPlane?: string;
    /**
    * Whether to automatically manage Service Mesh. Possible values: MANAGEMENT_UNSPECIFIED, MANAGEMENT_AUTOMATIC, MANAGEMENT_MANUAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#management GkeHubFeatureMembership#management}
    */
    readonly management?: string;
}
export declare function gkeHubFeatureMembershipMeshToTerraform(struct?: GkeHubFeatureMembershipMeshOutputReference | GkeHubFeatureMembershipMesh): any;
export declare class GkeHubFeatureMembershipMeshOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipMesh | undefined;
    set internalValue(value: GkeHubFeatureMembershipMesh | undefined);
    private _controlPlane?;
    get controlPlane(): string;
    set controlPlane(value: string);
    resetControlPlane(): void;
    get controlPlaneInput(): string | undefined;
    private _management?;
    get management(): string;
    set management(value: string);
    resetManagement(): void;
    get managementInput(): string | undefined;
}
export interface GkeHubFeatureMembershipTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#create GkeHubFeatureMembership#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#delete GkeHubFeatureMembership#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#update GkeHubFeatureMembership#update}
    */
    readonly update?: string;
}
export declare function gkeHubFeatureMembershipTimeoutsToTerraform(struct?: GkeHubFeatureMembershipTimeouts | cdktf.IResolvable): any;
export declare class GkeHubFeatureMembershipTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFeatureMembershipTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GkeHubFeatureMembershipTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership google_gke_hub_feature_membership}
*/
export declare class GkeHubFeatureMembership extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gke_hub_feature_membership";
    /**
    * Generates CDKTF code for importing a GkeHubFeatureMembership resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GkeHubFeatureMembership to import
    * @param importFromId The id of the existing GkeHubFeatureMembership that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GkeHubFeatureMembership to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.3.0/docs/resources/gke_hub_feature_membership google_gke_hub_feature_membership} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GkeHubFeatureMembershipConfig
    */
    constructor(scope: Construct, id: string, config: GkeHubFeatureMembershipConfig);
    private _feature?;
    get feature(): string;
    set feature(value: string);
    get featureInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _membership?;
    get membership(): string;
    set membership(value: string);
    get membershipInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _configmanagement;
    get configmanagement(): GkeHubFeatureMembershipConfigmanagementOutputReference;
    putConfigmanagement(value: GkeHubFeatureMembershipConfigmanagement): void;
    resetConfigmanagement(): void;
    get configmanagementInput(): GkeHubFeatureMembershipConfigmanagement | undefined;
    private _mesh;
    get mesh(): GkeHubFeatureMembershipMeshOutputReference;
    putMesh(value: GkeHubFeatureMembershipMesh): void;
    resetMesh(): void;
    get meshInput(): GkeHubFeatureMembershipMesh | undefined;
    private _timeouts;
    get timeouts(): GkeHubFeatureMembershipTimeoutsOutputReference;
    putTimeouts(value: GkeHubFeatureMembershipTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GkeHubFeatureMembershipTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
